@@ -7,8 +7,8 @@ from dnn_cool.visitors import LeafVisitor, VisitorOut, RootCompositeVisitor
 
 class FilterVisitor(LeafVisitor):
 
-    def __init__(self, task, prefix):
-        super().__init__(task, prefix)
+    def __init__(self, task, prefix, autograd):
+        super().__init__(task, prefix, autograd)
 
     def empty_result(self):
         return FilterParams(predictions={}, targets={})
@@ -36,8 +36,8 @@ class FilterParams(VisitorOut):
 
 class FilterCompositeVisitor(RootCompositeVisitor):
 
-    def __init__(self, task_flow, prefix):
-        super().__init__(task_flow, FilterVisitor, FilterParams, prefix=prefix)
+    def __init__(self, task_flow, prefix, autograd):
+        super().__init__(task_flow, FilterVisitor, FilterParams, prefix=prefix, autograd=autograd)
 
     def load_tuned(self, tuned_params):
         tasks = self.task_flow.get_all_children()
